Skip to contents

Use this function to generate more stratification inside you're strata file using sequencer and lanes. This is useful to test hypothesis of no missingness pattern associated with these variables or to generate missing genotypes based on these variables.

Usage

generate_sequencing_strata(
  strata,
  number.ind.per.lanes = 36,
  number.sequencer = NULL,
  randomize = FALSE,
  filename = NULL
)

Arguments

strata

The strata file used in grur, genometranslator, radr, and assigner is described in tidy_genome.

number.ind.per.lanes

(integer) By giving the number of individuals you want to pool per lanes, this will attribute a lane id to individual, sequentially. Default: number.ind.per.lanes = 36.

number.sequencer

(optional, integer) Give the number of sequencer used for this strata. Why sequencer ? so far I've seen numerous projects with missingness pattern with a sequencing signature. With default, number.sequencer = NULL, there is no column created in the strata file.

randomize

(optional, logical) To randomize the lanes for individuals and the sequencer used by each lanes. Default: randomize = FALSE.

filename

(optional) The name of the new strata file written to the working directory. Default: filename = NULL, the strata is only in the global environment.

Value

A strata object (dataframe) in the global environment with columns: POP_ID, INDIVIDUALS, LANES and optionally SEQUENCER.

Author

Thierry Gosselin thierrygosselin@icloud.com

Examples

if (FALSE) { # \dontrun{
new.strata <- generate_sequencing_strata(
strata = "my.strata.tsv",
number.ind.per.lanes = 48,
number.sequencer = 3,
randomize = TRUE,
filename = "my.new.strata.tsv"
)
} # }