Use this function to measure imputations accuracy and track impact of different algorithms on simulated or biological datasets.
Value
A list with information that were dropped from the analysis. This can be populations, individuals and markers. The accuracy measure returned the misclassification error (ME). The ME is provided by populations, individuals, markers and overall.
Author
Thierry Gosselin thierrygosselin@icloud.com