Will extract and tidy all simulations objects from a directory,
provided that the simulations were generated with simulate_rad.
Usage
tidy_sim(
sim.directory,
write.tidy = TRUE,
parallel.core = parallel::detectCores() - 1
)Arguments
- sim.directory
(character, path) Full path to the directory containing simulation objects.
- write.tidy
(logical, optional) The function uses
write.fst, to write the tidy data frame in the appropriate scenario directory. The file extension is.rad. Default:write.tidy = TRUE.- parallel.core
(integer, optional) The number of core used for parallel execution during extraction of simulated data. Default:
parallel::detectCores() - 1.
Value
A list with all the tidy data frames for all scenarios and iterations
generated by simulate_rad. Depending on argument values, the function also
write the tidy data in the appropriate folder.
Author
Thierry Gosselin thierrygosselin@icloud.com